@@ -8,8 +8,6 @@
 
 A CDK construct that provides an easy and [low-cost](#cost) ECS on EC2 server setup without a load balancer.
 
-**This construct is for development purposes only**. See [Limitations](#limitations).
-
 # Why
 
 ECS may often seem expensive when used for personal development purposes, due to the cost of the load balancer.
@@ -20,7 +18,7 @@ This construct aims to automate these works and make it easy to deploy resources
 
 # Try it out!
 
-The easiest way to try the construct is to clone this repository and deploy the sample server.
+The easiest way to try the construct is to clone this repository and deploy the sample Nginx server.
 Edit settings in `examples/minimum.ts` and deploy the cdk construct. [Public hosted zone](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/AboutHZWorkingWith.html) is required.
 
 ```
@@ -30,7 +28,7 @@ yarn install
 cdk deploy
 ```
 
-Access the configured `recordDomainNames` and see that the Nginx sample server has been deployed.
+Access the configured `recordDomainNames` and see that the sample Nginx server has been deployed.
 
 # Installation
 
@@ -193,7 +191,7 @@ class LowCostECS(
         log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
         record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
@@ -211,14 +209,34 @@ class LowCostECS(
         :param log_group: (experimental) Log group of the certbot task and the aws-cli task. Default: - Creates default cdk log group
         :param record_domain_names: (experimental) Domain names for A records to elastic ip of ECS host instance. Default: - [ props.hostedZone.zoneName ]
         :param removal_policy: (experimental) Removal policy for the file system and log group (if using default). Default: - RemovalPolicy.DESTROY
-        :param security_group: (experimental) Security group of the ECS host instance. Default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
+        :param security_groups: (experimental) Security group of the ECS host instance. Default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
         :param server_task_definition: (experimental) Task definition for the server ecs task. Default: - Nginx server task definition defined in sampleTaskDefinition()
-        :param vpc: (experimental) Vpc of the ECS host instance and cluster. Default: - Creates vpc with only public subnets and no NAT gateways.
+        :param vpc: (experimental) VPC of the ECS cluster and EFS file system. Default: - Creates vpc with only public subnets and no NAT gateways.
 
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LowCostECS.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                email: builtins.str,
+                hosted_zone_domain: builtins.str,
+                aws_cli_docker_tag: typing.Optional[builtins.str] = None,
+                certbot_docker_tag: typing.Optional[builtins.str] = None,
+                certbot_schedule_interval: typing.Optional[jsii.Number] = None,
+                container_insights: typing.Optional[builtins.bool] = None,
+                host_instance_spot_price: typing.Optional[builtins.str] = None,
+                host_instance_type: typing.Optional[builtins.str] = None,
+                log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
+                record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LowCostECSProps(
@@ -233,7 +251,7 @@ class LowCostECS(
             log_group=log_group,
             record_domain_names=record_domain_names,
             removal_policy=removal_policy,
-            security_group=security_group,
+            security_groups=security_groups,
             server_task_definition=server_task_definition,
             vpc=vpc,
         )
@@ -243,7 +261,8 @@ class LowCostECS(
     @builtins.property
     @jsii.member(jsii_name="certFileSystem")
     def cert_file_system(self) -> aws_cdk.aws_efs.FileSystem:
-        '''
+        '''(experimental) EFS file system that the SSL/TLS certificates are installed.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_efs.FileSystem, jsii.get(self, "certFileSystem"))
@@ -251,7 +270,8 @@ class LowCostECS(
     @builtins.property
     @jsii.member(jsii_name="cluster")
     def cluster(self) -> aws_cdk.aws_ecs.Cluster:
-        '''
+        '''(experimental) ECS cluster created in configured VPC.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ecs.Cluster, jsii.get(self, "cluster"))
@@ -259,7 +279,8 @@ class LowCostECS(
     @builtins.property
     @jsii.member(jsii_name="hostAutoScalingGroup")
     def host_auto_scaling_group(self) -> aws_cdk.aws_autoscaling.AutoScalingGroup:
-        '''
+        '''(experimental) ECS on EC2 service host instance autoscaling group.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_autoscaling.AutoScalingGroup, jsii.get(self, "hostAutoScalingGroup"))
@@ -267,7 +288,8 @@ class LowCostECS(
     @builtins.property
     @jsii.member(jsii_name="serverTaskDefinition")
     def server_task_definition(self) -> aws_cdk.aws_ecs.Ec2TaskDefinition:
-        '''
+        '''(experimental) Server task definition generated from LowCostECSTaskDefinitionOptions.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ecs.Ec2TaskDefinition, jsii.get(self, "serverTaskDefinition"))
@@ -275,27 +297,22 @@ class LowCostECS(
     @builtins.property
     @jsii.member(jsii_name="service")
     def service(self) -> aws_cdk.aws_ecs.Ec2Service:
-        '''
+        '''(experimental) ECS service of the server with desiredCount: 1, minHealthyPercent: 0, maxHealthyPercent: 100.
+
         :stability: experimental
+        :link: https://github.com/rajyan/low-cost-ecs#limitations
         '''
         return typing.cast(aws_cdk.aws_ecs.Ec2Service, jsii.get(self, "service"))
 
     @builtins.property
     @jsii.member(jsii_name="topic")
     def topic(self) -> aws_cdk.aws_sns.Topic:
-        '''
+        '''(experimental) SNS topic used to notify certbot renewal failure.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "topic"))
 
-    @builtins.property
-    @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        '''
-        :stability: experimental
-        '''
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
-
 
 @jsii.data_type(
     jsii_type="low-cost-ecs.LowCostECSProps",
@@ -312,7 +329,7 @@ class LowCostECS(
         "log_group": "logGroup",
         "record_domain_names": "recordDomainNames",
         "removal_policy": "removalPolicy",
-        "security_group": "securityGroup",
+        "security_groups": "securityGroups",
         "server_task_definition": "serverTaskDefinition",
         "vpc": "vpc",
     },
@@ -332,7 +349,7 @@ class LowCostECSProps:
         log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
         record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
@@ -348,16 +365,34 @@ class LowCostECSProps:
         :param log_group: (experimental) Log group of the certbot task and the aws-cli task. Default: - Creates default cdk log group
         :param record_domain_names: (experimental) Domain names for A records to elastic ip of ECS host instance. Default: - [ props.hostedZone.zoneName ]
         :param removal_policy: (experimental) Removal policy for the file system and log group (if using default). Default: - RemovalPolicy.DESTROY
-        :param security_group: (experimental) Security group of the ECS host instance. Default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
+        :param security_groups: (experimental) Security group of the ECS host instance. Default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
         :param server_task_definition: (experimental) Task definition for the server ecs task. Default: - Nginx server task definition defined in sampleTaskDefinition()
-        :param vpc: (experimental) Vpc of the ECS host instance and cluster. Default: - Creates vpc with only public subnets and no NAT gateways.
+        :param vpc: (experimental) VPC of the ECS cluster and EFS file system. Default: - Creates vpc with only public subnets and no NAT gateways.
 
         :stability: experimental
         '''
         if isinstance(server_task_definition, dict):
             server_task_definition = LowCostECSTaskDefinitionOptions(**server_task_definition)
         if __debug__:
-            type_hints = typing.get_type_hints(LowCostECSProps.__init__)
+            def stub(
+                *,
+                email: builtins.str,
+                hosted_zone_domain: builtins.str,
+                aws_cli_docker_tag: typing.Optional[builtins.str] = None,
+                certbot_docker_tag: typing.Optional[builtins.str] = None,
+                certbot_schedule_interval: typing.Optional[jsii.Number] = None,
+                container_insights: typing.Optional[builtins.bool] = None,
+                host_instance_spot_price: typing.Optional[builtins.str] = None,
+                host_instance_type: typing.Optional[builtins.str] = None,
+                log_group: typing.Optional[aws_cdk.aws_logs.ILogGroup] = None,
+                record_domain_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                server_task_definition: typing.Optional[typing.Union["LowCostECSTaskDefinitionOptions", typing.Dict[str, typing.Any]]] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument email", value=email, expected_type=type_hints["email"])
             check_type(argname="argument hosted_zone_domain", value=hosted_zone_domain, expected_type=type_hints["hosted_zone_domain"])
             check_type(argname="argument aws_cli_docker_tag", value=aws_cli_docker_tag, expected_type=type_hints["aws_cli_docker_tag"])
@@ -369,7 +404,7 @@ class LowCostECSProps:
             check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
             check_type(argname="argument record_domain_names", value=record_domain_names, expected_type=type_hints["record_domain_names"])
             check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
-            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
             check_type(argname="argument server_task_definition", value=server_task_definition, expected_type=type_hints["server_task_definition"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -394,8 +429,8 @@ class LowCostECSProps:
             self._values["record_domain_names"] = record_domain_names
         if removal_policy is not None:
             self._values["removal_policy"] = removal_policy
-        if security_group is not None:
-            self._values["security_group"] = security_group
+        if security_groups is not None:
+            self._values["security_groups"] = security_groups
         if server_task_definition is not None:
             self._values["server_task_definition"] = server_task_definition
         if vpc is not None:
@@ -528,15 +563,17 @@ class LowCostECSProps:
         return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     @builtins.property
-    def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
+    def security_groups(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]]:
         '''(experimental) Security group of the ECS host instance.
 
         :default: - Creates security group with allowAllOutbound and ingress rule (ipv4, ipv6) => (tcp 80, 443).
 
         :stability: experimental
         '''
-        result = self._values.get("security_group")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.ISecurityGroup], result)
+        result = self._values.get("security_groups")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]], result)
 
     @builtins.property
     def server_task_definition(
@@ -554,7 +591,7 @@ class LowCostECSProps:
 
     @builtins.property
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        '''(experimental) Vpc of the ECS host instance and cluster.
+        '''(experimental) VPC of the ECS cluster and EFS file system.
 
         :default: - Creates vpc with only public subnets and no NAT gateways.
 
@@ -602,7 +639,14 @@ class LowCostECSTaskDefinitionOptions:
         if isinstance(task_definition, dict):
             task_definition = aws_cdk.aws_ecs.Ec2TaskDefinitionProps(**task_definition)
         if __debug__:
-            type_hints = typing.get_type_hints(LowCostECSTaskDefinitionOptions.__init__)
+            def stub(
+                *,
+                containers: typing.Sequence[typing.Union[aws_cdk.aws_ecs.ContainerDefinitionOptions, typing.Dict[str, typing.Any]]],
+                task_definition: typing.Optional[typing.Union[aws_cdk.aws_ecs.Ec2TaskDefinitionProps, typing.Dict[str, typing.Any]]] = None,
+                volumes: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.Volume, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument containers", value=containers, expected_type=type_hints["containers"])
             check_type(argname="argument task_definition", value=task_definition, expected_type=type_hints["task_definition"])
             check_type(argname="argument volumes", value=volumes, expected_type=type_hints["volumes"])
